# v0.1.33 2023-01-05
- Refactoring: added multithreading for synchronous requests by using exisiting event loop for idempotency check to improve performance

# v0.1.32 2023-01-05
- Fix: query string parsing
- New: added Request info to verbose mode

# v0.1.31 2023-01-05
- Fix: header parser

# v0.1.30 2023-01-05
- Fix: empty URL in Postman collection item

# v0.1.29 2023-01-05
- Fix: flattened nested folders of Postman collection file using DFS

# v0.1.28 2022-12-28
- Health check
- Idempotency check
- Other minor fixes